local Util = require("mer.itemBrowser.util")
local config = require("mer.itemBrowser.config")
local mcmConfig = mwse.loadConfig(config.configPath, config.mcmDefault)

local LINKS_LIST = {
    {
        text = "Historique (VO)",
        url = "https://github.com/jhaakma/item-browser/releases"
    },
    -- {
    --     text = "Wiki",
    --     url = "https://github.com/jhaakma/crafting-framework/wiki"
    -- },
    {
        text = "Page Nexus",
        url = "https://www.nexusmods.com/morrowind/mods/51366"
    },
    {
        text = "Ko-fi",
        url = "https://ko-fi.com/merlord"
    },
}
local CREDITS_LIST = {
    {
        text = "Par Merlord",
        url = "https://www.nexusmods.com/users/3040468?tab=user+files",
    },
}

local function addSideBar(component)
    local versionText = string.format("Menu des objets")
    component.sidebar:createCategory(versionText)
    component.sidebar:createInfo{ text = config.static.modDescription }

    local linksCategory = component.sidebar:createCategory("Liens")
    for _, link in ipairs(LINKS_LIST) do
        linksCategory:createHyperLink{ text = link.text, url = link.url }
    end
    local creditsCategory = component.sidebar:createCategory("Crdits")
    for _, credit in ipairs(CREDITS_LIST) do
        creditsCategory:createHyperLink{ text = credit.text, url = credit.url }
    end
end

local function registerMCM()
    local template = mwse.mcm.createTemplate{ name = config.static.modName }
    template.onClose = function()
        config.save(mcmConfig)
    end
    template:register()

    local page = template:createSideBarPage{ label = "Paramtres"}
    addSideBar(page)

    page:createYesNoButton{
        label = "Activer le mod",
        description = "Active ou dsactive le mod. La premire activation lors d'une session de jeu peut tre accompagne d'un lger dlai puisqu'il faudra un peu de temps pour tenir compte de toutes les recettes.",
        variable = mwse.mcm.createTableVariable{ id = "enabled", table = mcmConfig },
        callback = function(self)
            if self.variable.value == true then
                event.trigger("ItemBrowser:RegisterMenus")
            end
        end
    }

    page:createKeyBinder{
        label = "Raccourci",
        description = "La combinaison de touches pour activer le menu des objets.",
        variable = mwse.mcm.createTableVariable{ id = "hotKey", table = mcmConfig },
        allowCombinations = true
    }

    page:createDropdown{
        description = "Dfinit le niveau de journalisation du mod pour le fichier mwse.log. Laissez-le sur INFO  moins que vous n'ayez besoin de faire du dbuggage.",
        options = {
            { label = "TRACE", value = "TRACE"},
            { label = "DEBUG", value = "DEBUG"},
            { label = "INFO", value = "INFO"},
            { label = "ERROR", value = "ERROR"},
            { label = "NONE", value = "NONE"},
        },
        variable =  mwse.mcm.createTableVariable{ id = "logLevel", table = mcmConfig, default = config.mcmDefault.logLevel},
        callback = function(self)
            for _, logger in pairs(Util.loggers) do
                logger:setLogLevel(self.variable.value)
            end
        end
    }
end
event.register("modConfigReady", registerMCM)
